@@ -18,8 +18,11 @@ def lint_content(config_content, lint_spec: LinterSpec):
         ):
             start_offset = start_mo.end() + 1
 
-    if not end_offset and lint_spec.config_ends_at:
-        end_offset = config_content.rfind("\n" + lint_spec.config_ends_at)
+    if lint_spec.config_ends_at:
+        # if not found, rfind returns -1 to indciate; therefore need to make
+        # this check
+        if (found := config_content.rfind("\n" + lint_spec.config_ends_at)) > 0:
+            end_offset = found
 
     config_content = config_content[start_offset:end_offset]
 
@@ -30,13 +33,18 @@ def lint_content(config_content, lint_spec: LinterSpec):
     return config_content
 
 
-def lint_file(fileobj: Path, lint_spec):
+def lint_file(fileobj: Path, lint_spec) -> bool:
+    """
+    Perform the linting function on the content in the given file.
+    Returns True if the content was changed, False otherwise.
+    """
     orig_config_content = fileobj.read_text()
 
     config_content = lint_content(orig_config_content, lint_spec)
     if config_content == orig_config_content:
         log.debug(f"LINT no change on {fileobj.name}")
-        return
+        return False
 
     fileobj.rename(str(fileobj.absolute()) + ".orig")
     fileobj.write_text(config_content)
+    return True
