@@ -1,9 +1,25 @@
+"""
+This module contains the probe coroutine used to validate that a target device
+has a given port open.
+"""
+
+# -----------------------------------------------------------------------------
+# System Imports
+# -----------------------------------------------------------------------------
+
 import asyncio
 
 __all__ = ["probe"]
 
 
-async def probe(host, port=22, timeout=10, raise_exc=False) -> bool:
+# -----------------------------------------------------------------------------
+#
+#                              CODE BEGINS
+#
+# -----------------------------------------------------------------------------
+
+
+async def probe(host, timeout: int, port=22, raise_exc=False) -> bool:
     """
     Coroutine used to determine if a host port is online and available.
 
